Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1843)

Unified Diff: chrome/test/automation/automation_proxy_uitest.h

Issue 5139001: Revert 66350 - Add named testing interface. This allows you to connect to a p... (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: Created 10 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/test/automation/automation_proxy.cc ('k') | chrome/test/automation/automation_proxy_uitest.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/test/automation/automation_proxy_uitest.h
===================================================================
--- chrome/test/automation/automation_proxy_uitest.h (revision 66367)
+++ chrome/test/automation/automation_proxy_uitest.h (working copy)
@@ -112,10 +112,10 @@
class ExternalTabUITest : public UITest {
public:
ExternalTabUITest() : UITest(MessageLoop::TYPE_UI) {}
// Override UITest's CreateProxyLauncher to provide the unit test
// with our special implementation of AutomationProxy.
- // This function is called from within UITest::SetUp().
- virtual ProxyLauncher* CreateProxyLauncher();
+ // This function is called from within UITest::LaunchBrowserAndServer.
+ virtual AutomationProxy* CreateAutomationProxy(int execution_timeout);
protected:
// Filtered Inet will override automation callbacks for network resources.
virtual bool ShouldFilterInet() {
@@ -112,10 +112,10 @@
public:
ExternalTabUITest() : UITest(MessageLoop::TYPE_UI) {}
- // Override UITest's CreateProxyLauncher to provide the unit test
+ // Override UITest's CreateAutomationProxy to provide the unit test
// with our special implementation of AutomationProxy.
« no previous file with comments | « chrome/test/automation/automation_proxy.cc ('k') | chrome/test/automation/automation_proxy_uitest.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698